@@ -66,7 +66,7 @@ class CodeGenerator(object):
         if len(self.message_sets) == 0:
             return 0
 
-        return max(len(list(message_set.active_signals()))
+        return max(len(list(message_set.enabled_signals()))
                 for message_set in self.message_sets)
 
     def _build_header(self):
@@ -88,7 +88,7 @@ class CodeGenerator(object):
         return "    { %d, \"%s\", %d, %d, %d, %d }," % (index, message_set.name,
                 len(list(message_set.valid_buses())),
                 len(list(message_set.active_messages())),
-                len(list(message_set.active_signals())),
+                len(list(message_set.enabled_signals())),
                 len(list(message_set.active_commands())))
 
     def _build_messages(self):
@@ -100,7 +100,7 @@ class CodeGenerator(object):
         def block(message_set):
             lines = []
             for message_index, message in enumerate(message_set.all_messages()):
-                if not message.enabled:
+                if not message.active:
                     LOG.warning("Skipping disabled message %s (0x%x)" %
                             (message.name, message.id))
                     continue
@@ -190,7 +190,7 @@ class CodeGenerator(object):
         def block(message_set, **kwargs):
             states_index = 0
             lines = []
-            for signal in message_set.active_signals():
+            for signal in message_set.enabled_signals():
                 if len(signal.states) > 0:
                     line = "        { "
                     for state_count, state in enumerate(signal.sorted_states):
@@ -311,29 +311,27 @@ class CodeGenerator(object):
                 lines.append(" " * 8 + "case %s:" % bus.controller)
                 lines.append(" " * 12 + "switch (id) {")
                 for message in bus.active_messages():
-                    lines.append(" " * 12 + "case 0x%x: // %s" % (message.id,
-                            message.name))
-                    for handler in message.handlers:
-                        lines.append(" " * 16 + "%s(id, data, SIGNALS[%d], " % (
-                            handler, message_set.index) +
-                                "getSignalCount(), pipeline);")
-                    for signal in sorted((s for s in message.signals.values()),
-                            key=operator.attrgetter('generic_name')):
-                        if not signal.enabled or signal.ignore:
-                            continue
-                        line = " " * 16
-                        line += ("can::read::translateSignal(pipeline, "
-                                    "&SIGNALS[%d][%d], data, " %
-                                    (message_set.index, signal.array_index))
-                        if signal.handler:
-                            line += "&%s, " % signal.handler
-                        line += ("SIGNALS[%d], getSignalCount()); // %s" % (
-                            message_set.index, signal.name))
-                        lines.append(line)
-                    lines.append("                break;")
+                    if (len(list(message.active_signals())) > 0 or
+                            len(list(message.handlers)) > 0):
+                        lines.append(" " * 12 + "case 0x%x: // %s" % (message.id,
+                                message.name))
+                        for handler in message.handlers:
+                            lines.append(" " * 16 + "%s(id, data, SIGNALS[%d], " % (
+                                handler, message_set.index) +
+                                    "getSignalCount(), pipeline);")
+                        for signal in message.active_signals():
+                            line = " " * 16
+                            line += ("can::read::translateSignal(pipeline, "
+                                        "&SIGNALS[%d][%d], data, " %
+                                        (message_set.index, signal.array_index))
+                            if signal.handler:
+                                line += "&%s, " % signal.handler
+                            line += ("SIGNALS[%d], getSignalCount()); // %s" % (
+                                message_set.index, signal.name))
+                            lines.append(line)
+                        lines.append("                break;")
                 lines.append("            }")
-                if (len(list(bus.active_messages())) == 0 or
-                        bus.raw_can_mode != "off"):
+                if bus.raw_can_mode != "off":
                     lines.append(" " * 12 + "openxc::can::read::passthroughMessage("
                             "bus, id, data, getMessages(), getMessageCount(), pipeline);")
                 lines.append("            break;")
