@@ -32,6 +32,11 @@ class Message(object):
         self.force_send_changed_signals = False
         self.signals = defaultdict(Signal)
 
+    @property
+    def active(self):
+        return self.enabled and (len(list(self.enabled_signals())) > 0
+                or len(self.handlers) > 0)
+
     @property
     def id(self):
         return getattr(self, '_id', None)
@@ -117,10 +122,22 @@ class Message(object):
         return True
 
     def sorted_signals(self):
-        for signal in sorted(self.signals.values(),
+        for signal in sorted(self.enabled_signals(),
                 key=operator.attrgetter('generic_name')):
             yield signal
 
+    def enabled_signals(self):
+        for signal in self.signals.values():
+            if signal.enabled:
+                yield signal
+
+    def active_signals(self):
+        """An active signal is one that's enabled and not ignored, i.e. it
+        should be translated.
+        """
+        for signal in self.sorted_signals():
+            if not signal.ignore:
+                yield signal
 
     def to_dict(self):
         return {"name": self.name,
@@ -174,9 +191,14 @@ class CanBus(object):
 
     def active_messages(self):
         for message in self.sorted_messages():
-            if message.enabled:
+            if message.active:
                 yield message
 
+    def enabled_signals(self):
+        for message in self.active_messages():
+            for signal in message.enabled_signals():
+                yield signal
+
     def sorted_messages(self):
         for message in sorted(self.messages.values(),
                 key=operator.attrgetter('id')):
